@@ -21,20 +21,23 @@
 /* ************************************************************************** */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "export.h"
-#include "./gsb_assistant.h"
-#include "./export_csv.h"
-#include "./gsb_data_account.h"
-#include "./gsb_file.h"
-#include "./dialog.h"
-#include "./utils.h"
-#include "./qif.h"
-#include "./structures.h"
-#include "./include.h"
+#include "gsb_assistant.h"
+#include "export_csv.h"
+#include "gsb_data_account.h"
+#include "gsb_file.h"
+#include "dialog.h"
+#include "utils.h"
+#include "qif.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 
@@ -362,7 +365,7 @@ GtkWidget * create_export_account_resume_page ( struct exported_account * accoun
 
     /* Layout */
     hbox = gtk_hbox_new ( FALSE, 6 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), gtk_label_new ( COLON ( _("Export format") ) ),
+    gtk_box_pack_start ( GTK_BOX ( hbox ), gtk_label_new ( _("Export format: ") ),
 			 FALSE, FALSE, 0 );
 
     /* Combo box */
