@@ -1,5 +1,5 @@
 /* ************************************************************************** */
-/* This file manage cvs export format                                         */
+/* This file manage CSV export format                                         */
 /*                                                                            */
 /*     Copyright (C)    2004 François Terrot (francois.terrot at grisbi.org)  */
 /*          2005 Alain Portal (aportal@univ-montp2.fr)                        */
@@ -27,42 +27,52 @@
  * \todo make the CSV parameter configurable 
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "export_csv.h"
-#include "./dialog.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_reconcile.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_file_util.h"
-#include "./gsb_real.h"
-#include "./main.h"
-#include "./utils_str.h"
-#include "./utils_files.h"
-#include "./gsb_data_transaction.h"
-#include "./include.h"
-#include "./gsb_real.h"
+#include "dialog.h"
+#include "gsb_data_account.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_transaction.h"
+#include "gsb_file_util.h"
+#include "gsb_real.h"
+#include "main.h"
+#include "utils_str.h"
+#include "utils_files.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static  void csv_add_record(FILE* file,
+static void csv_add_record(FILE* file,
 			   gboolean clear_all,
 			   gboolean print_balance );
-static  void csv_clear_fields(gboolean clear_all);
-static  FILE *gsb_csv_export_open_file ( const gchar *filename );
-static  gboolean gsb_csv_export_title_line ( FILE *csv_file,
+static void csv_clear_fields(gboolean clear_all);
+static FILE *gsb_csv_export_open_file ( const gchar *filename );
+gboolean gsb_csv_export_sort_by_value_date_or_date ( gpointer transaction_pointer_1, 
+                        gpointer transaction_pointer_2 );
+static gboolean gsb_csv_export_title_line ( FILE *csv_file,
 					    gboolean print_balance );
-static  gboolean gsb_csv_export_transaction ( gint transaction_number,
+static gboolean gsb_csv_export_transaction ( gint transaction_number,
 					     FILE *csv_file,
 					     gboolean print_balance );
+static gboolean gsb_csv_export_tree_view_list_foreach_callback ( GtkTreeModel *model,
+                        GtkTreePath *path,
+                        GtkTreeIter *iter,
+                        FILE *csv_file );
+static void gsb_csv_export_tree_view_list_export_rows ( FILE *csv_file, GtkTreeView *tree_view );
+static void gsb_csv_export_tree_view_list_export_title_line ( FILE *csv_file, GtkTreeView *tree_view );
+
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -319,6 +329,8 @@ gboolean gsb_csv_export_account ( const gchar *filename, gint account_nb )
 
     /* export the transactions */
     pTransactionList = gsb_data_transaction_get_transactions_list ();
+    pTransactionList = g_slist_sort ( pTransactionList,
+                        (GCompareFunc) gsb_csv_export_sort_by_value_date_or_date );
     while ( pTransactionList )
     {
 	gint pTransaction = gsb_data_transaction_get_transaction_number (pTransactionList -> data);
@@ -343,8 +355,7 @@ gboolean gsb_csv_export_account ( const gchar *filename, gint account_nb )
  *
  * \return TRUE ok, FALSE problem
  * */
-gboolean gsb_csv_export_archive ( const gchar *filename,
-				  gint archive_number )
+gboolean gsb_csv_export_archive ( const gchar *filename, gint archive_number )
 {
     FILE *csv_file;
     GSList *pTransactionList;
@@ -386,19 +397,20 @@ gboolean gsb_csv_export_archive ( const gchar *filename,
 static FILE *gsb_csv_export_open_file ( const gchar *filename )
 {
     FILE *csv_file;
-    gchar *sMessage = NULL;
 
-    if (!gsb_file_util_test_overwrite (filename))
-	return NULL;
-
-    /* Ouverture du fichier, si pb, on marque l'erreur et passe au fichier suivant */
-    if ( !( csv_file = utf8_fopen ( filename, "w" ) ))
+    /* Création du fichier, si pb, on marque l'erreur et passe au fichier suivant */
+    csv_file = utf8_fopen ( filename, "w" );
+    if ( ! csv_file )
     {
-	sMessage = g_strdup_printf ( _("Error opening file \"%s\" :\n%s"),
-				     filename, strerror ( errno ) );
-	dialogue ( sMessage );
-	g_free ( sMessage );
-	return NULL;
+        gchar *sMessage = NULL;
+
+        sMessage = g_strdup_printf ( _("Unable to create file \"%s\" :\n%s"),
+                         filename, g_strerror ( errno ) );
+        dialogue ( sMessage );
+
+        g_free ( sMessage );
+
+        return NULL;
     }
 
     return csv_file;
@@ -443,9 +455,9 @@ static gboolean gsb_csv_export_transaction ( gint transaction_number,
 	{
 	    CSV_CLEAR_FIELD (csv_field_date);
 	    csv_field_date = g_strdup_printf ("%d/%d/%d", 
-					      g_date_day ( date ), 
-					      g_date_month ( date ),
-					      g_date_year ( date ) );
+					      g_date_get_day ( date ), 
+					      g_date_get_month ( date ),
+					      g_date_get_year ( date ) );
 	}
 
 	value_date = gsb_data_transaction_get_value_date ( transaction_number );
@@ -453,9 +465,9 @@ static gboolean gsb_csv_export_transaction ( gint transaction_number,
 	{
 	    CSV_CLEAR_FIELD (csv_field_date_val);
 	    csv_field_date_val = g_strdup_printf ("%d/%d/%d", 
-						  g_date_day ( value_date ), 
-						  g_date_month ( value_date ),
-						  g_date_year ( value_date ) );
+						  g_date_get_day ( value_date ), 
+						  g_date_get_month ( value_date ),
+						  g_date_get_year ( value_date ) );
 	}
 
 	/* met le pointage */
@@ -590,7 +602,7 @@ static gboolean gsb_csv_export_transaction ( gint transaction_number,
 		{
 		    /* on commence par mettre la catég et sous categ de l'opé et de l'opé de ventilation */
 		    CSV_CLEAR_FIELD (csv_field_ventil);
-		    csv_field_ventil = my_strdup (_("B")); // -> mark 
+		    csv_field_ventil = my_strdup (_("B")); /* -> mark */
 
 		    CSV_CLEAR_FIELD (csv_field_operation);
 		    csv_field_operation = g_strdup_printf("%d", pSplitTransaction );
@@ -815,6 +827,173 @@ static gboolean gsb_csv_export_title_line ( FILE *csv_file,
     return TRUE;
 }
 
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+gboolean gsb_csv_export_tree_view_list ( const gchar *filename, GtkTreeView *tree_view )
+{
+    FILE *csv_file;
+
+    csv_file = gsb_csv_export_open_file ( filename );
+    if ( !csv_file )
+        return FALSE;
+
+    gsb_csv_export_tree_view_list_export_title_line ( csv_file, tree_view );
+    gsb_csv_export_tree_view_list_export_rows ( csv_file, tree_view );
+
+    fclose ( csv_file );
+
+    return TRUE;
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+static void gsb_csv_export_tree_view_list_export_title_line ( FILE *csv_file, GtkTreeView *tree_view )
+{
+    GList *list;
+    GList *list_tmp;
+
+    list = gtk_tree_view_get_columns ( tree_view );
+    list_tmp = list;
+
+    while ( list_tmp )
+    {
+        GtkTreeViewColumn *col;
+        const gchar *text;
+
+        col = ( GtkTreeViewColumn * ) list_tmp -> data;
+
+        /* get the text */
+        text = gtk_tree_view_column_get_title ( col );
+
+        CSV_STR_FIELD( csv_file, text );
+
+        list_tmp  = list_tmp -> next;
+    }
+    CSV_END_RECORD( csv_file );
+}
+
+
+/**
+ *
+ *
+ *
+ *
+ * */
+static void gsb_csv_export_tree_view_list_export_rows ( FILE *csv_file, GtkTreeView *tree_view )
+{
+    GtkTreeModel *model;
+
+    model = gtk_tree_view_get_model ( tree_view );
+    g_object_set_data ( G_OBJECT ( model ), "tree_view", tree_view );
+
+    gtk_tree_model_foreach ( model,
+                        ( GtkTreeModelForeachFunc ) gsb_csv_export_tree_view_list_foreach_callback,
+                        csv_file );
+
+    g_object_steal_data ( G_OBJECT ( model ), "tree_view" );
+}
+
+
+
+static gboolean gsb_csv_export_tree_view_list_foreach_callback ( GtkTreeModel *model,
+                        GtkTreePath *path,
+                        GtkTreeIter *iter,
+                        FILE *csv_file )
+{
+    GtkTreeView *tree_view;
+    GList *list;
+    GList *list_tmp;
+
+    tree_view = g_object_get_data ( G_OBJECT ( model ), "tree_view" );
+    list = gtk_tree_view_get_columns ( tree_view );
+    list_tmp = list;
+
+    while ( list_tmp )
+    {
+        GtkTreeViewColumn *col;
+        gchar *text;
+        gint col_num_model;
+        GType col_type_model;
+
+        col = list_tmp -> data;
+
+        col_num_model = GPOINTER_TO_INT ( g_object_get_data ( G_OBJECT ( col ), "num_col_model" ) );
+        col_type_model = gtk_tree_model_get_column_type ( model, col_num_model );
+
+        /* get the text */
+        if ( col_type_model == G_TYPE_STRING )
+            gtk_tree_model_get ( model, iter, col_num_model, &text, -1 );
+        else if ( col_type_model == G_TYPE_INT )
+        {
+            gint number;
+
+            gtk_tree_model_get ( model, iter, col_num_model, &number, -1 );
+            text = utils_str_itoa ( number );
+        }
+        else
+            text = NULL;
+
+        CSV_STR_FIELD ( csv_file, text );
+        CSV_CLEAR_FIELD ( text );
+
+        list_tmp  = list_tmp -> next;
+    }
+
+    CSV_END_RECORD( csv_file );
+
+    return FALSE;
+}
+
+
+/**
+ * used to compare 2 iters and sort the by value date or date if not exist
+ * always put the white line below
+ * 
+ * \param iter_1
+ * \param iter_2
+ * 
+ * \return -1 if iter_1 is before iter_2
+ * */
+gint gsb_csv_export_sort_by_value_date_or_date ( gpointer transaction_pointer_1, 
+                        gpointer transaction_pointer_2 )
+{
+    gint transaction_number_1;
+    gint transaction_number_2;
+    const GDate *value_date_1;
+    const GDate *value_date_2;
+
+
+    transaction_number_1 = gsb_data_transaction_get_transaction_number (
+                        transaction_pointer_1 );
+    transaction_number_2 = gsb_data_transaction_get_transaction_number (
+                        transaction_pointer_2 );
+
+    value_date_1 = gsb_data_transaction_get_value_date ( transaction_number_1 );
+    if ( ! value_date_1 )
+        value_date_1 = gsb_data_transaction_get_date ( transaction_number_1 );
+
+    value_date_2 = gsb_data_transaction_get_value_date ( transaction_number_2 );
+    if ( ! value_date_2 )
+        value_date_2 = gsb_data_transaction_get_date ( transaction_number_2 );
+
+    if ( value_date_1 )
+        return ( g_date_compare ( value_date_1, value_date_2 ) );
+    else
+        return -1;
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
