@@ -29,27 +29,29 @@
  * (for changes on internal structure in gsb_data_x_set_x, see gsb_autofunc.c)
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "gsb_automem.h"
-#include "./utils_editables.h"
-#include "./traitement_variables.h"
-#include "./utils_str.h"
-#include "./utils_buttons.h"
-#include "./utils.h"
-#include "./structures.h"
-#include "./utils_buttons.h"
-#include "./include.h"
+#include "utils_editables.h"
+#include "traitement_variables.h"
+#include "utils_str.h"
+#include "utils_buttons.h"
+#include "utils.h"
+#include "structures.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
-static  gboolean gsb_automem_checkbutton_changed ( GtkWidget *checkbutton,
+static gboolean gsb_automem_checkbutton_changed ( GtkWidget *checkbutton,
 						  gpointer null );
-static  gboolean gsb_automem_entry_changed (GtkWidget *entry,
+static gboolean gsb_automem_entry_changed (GtkWidget *entry,
 					   gpointer null );
-static  gboolean gsb_automem_spin_button_changed ( GtkWidget *spin,
+static gboolean gsb_automem_spin_button_changed ( GtkWidget *spin,
 						  gpointer null);
 static GtkWidget *gsb_automem_spin_button_new_full ( gint *value, 
 					      gdouble lower, gdouble upper, 
@@ -57,7 +59,7 @@ static GtkWidget *gsb_automem_spin_button_new_full ( gint *value,
 					      gdouble page_size, 
 					      gdouble climb_rate,
 					      GCallback hook, gpointer data );
-static  gboolean gsb_automem_textview_changed ( GtkTextBuffer *buffer,
+static gboolean gsb_automem_textview_changed ( GtkTextBuffer *buffer,
 					       gpointer null );
 /*END_STATIC*/
 
@@ -504,22 +506,24 @@ GtkWidget *gsb_automem_radiobutton_new ( const gchar *choice1,
  *
  * \return A newly created paddingbox
  */
-/*GtkWidget *gsb_automem_radiobutton3_new_with_title ( GtkWidget *parent,
+GtkWidget *gsb_automem_radiobutton3_new_with_title ( GtkWidget *parent,
 						const gchar *title,
 					    const gchar *choice1, const gchar *choice2, const gchar *choice3,
-					    gboolean *value,
+					    gint *value,
 					    GCallback hook,
-					    gpointer data )
+					    gpointer data,
+                        gint orientation )
 {
     GtkWidget *paddingbox;
 
-    paddingbox = new_paddingbox_with_title (parent, FALSE, COLON(title));
-    gtk_box_pack_start (GTK_BOX(paddingbox),
+    paddingbox = new_paddingbox_with_title ( parent, FALSE, title );
+
+    gtk_box_pack_start ( GTK_BOX ( paddingbox ),
 			gsb_automem_radiobutton3_new ( choice1, choice2, choice3,
-						       value, hook, data ), 
+						       value, hook, data, orientation ),
 			FALSE, FALSE, 0 );
     return paddingbox;
-}*/
+}
 
 
 
@@ -542,29 +546,33 @@ GtkWidget *gsb_automem_radiobutton3_new ( const gchar *choice1,
 					    const gchar *choice3,
 					    gint *value,
 					    GCallback callback,
-					    gpointer data )
+					    gpointer data,
+                        gint orientation )
 {
-    GtkWidget *hbox;
+    GtkWidget *box;
     GtkWidget *button1;
     GtkWidget *button2;
     GtkWidget *button3 = NULL;
 
-    hbox = gtk_hbox_new ( FALSE, 6 );
+    if ( orientation == GTK_ORIENTATION_HORIZONTAL )
+        box = gtk_hbox_new ( FALSE, 6 );
+    else
+        box = gtk_vbox_new ( FALSE, 6 );
 
     button1 = gtk_radio_button_new_with_mnemonic ( NULL, choice1 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button1, FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( box ), button1, FALSE, FALSE, 0 );
 
     button2 = gtk_radio_button_new_with_mnemonic ( gtk_radio_button_get_group (
-                        GTK_RADIO_BUTTON ( button1 ) ), 
+                        GTK_RADIO_BUTTON ( button1 ) ),
 						choice2 );
-    gtk_box_pack_start ( GTK_BOX ( hbox ), button2, FALSE, FALSE, 0 );
+    gtk_box_pack_start ( GTK_BOX ( box ), button2, FALSE, FALSE, 0 );
 
     if ( choice3 && strlen ( choice3 ) )
     {
         button3 = gtk_radio_button_new_with_mnemonic ( gtk_radio_button_get_group (
-                        GTK_RADIO_BUTTON ( button1 ) ), 
+                        GTK_RADIO_BUTTON ( button1 ) ),
 						choice3 );
-        gtk_box_pack_start ( GTK_BOX ( hbox ), button3, FALSE, FALSE, 0 );
+        gtk_box_pack_start ( GTK_BOX ( box ), button3, FALSE, FALSE, 0 );
     }
 
     if (value)
@@ -596,13 +604,13 @@ GtkWidget *gsb_automem_radiobutton3_new ( const gchar *choice1,
 
     if ( callback )
     {
-	    g_signal_connect ( G_OBJECT ( button1 ), "released", G_CALLBACK ( callback ), data );
-        g_signal_connect ( G_OBJECT ( button2 ), "released", G_CALLBACK ( callback ), data );
+	    g_signal_connect ( G_OBJECT ( button1 ), "button-release-event", G_CALLBACK ( callback ), data );
+        g_signal_connect ( G_OBJECT ( button2 ), "button-release-event", G_CALLBACK ( callback ), data );
         if ( button3 )
-            g_signal_connect ( G_OBJECT ( button3 ), "released", G_CALLBACK ( callback ), data );
+            g_signal_connect ( G_OBJECT ( button3 ), "button-release-event", G_CALLBACK ( callback ), data );
     }
  
-    return hbox;
+    return box;
 }
 
 
@@ -798,12 +806,12 @@ GtkWidget *gsb_automem_stock_button_new ( GsbButtonStyle style,
     {
 	if ( data >= 0 )
 	{
-	    g_signal_connect_swapped ( G_OBJECT(button), "pressed", 
+	    g_signal_connect_swapped ( G_OBJECT(button), "clicked", 
 				       G_CALLBACK(callback), data );
 	}
 	else
 	{
-	    g_signal_connect ( G_OBJECT(button), "pressed", 
+	    g_signal_connect ( G_OBJECT(button), "clicked", 
 			       G_CALLBACK(callback), data );
 	}
     }
