@@ -26,16 +26,18 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 
 /*START_INCLUDE*/
 #include "gsb_data_payment.h"
-#include "./gsb_data_account.h"
-#include "./utils_str.h"
-#include "./gsb_data_account.h"
-#include "./include.h"
-#include "./erreur.h"
+#include "gsb_data_account.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 
@@ -63,7 +65,7 @@ static GSList *payment_list = NULL;
 static struct_payment *payment_buffer;
 
 /*START_STATIC*/
-static  void _gsb_data_payment_free ( struct_payment *payment );
+static void _gsb_data_payment_free ( struct_payment *payment );
 static struct_payment *gsb_data_payment_get_structure ( gint payment_number );
 static gint gsb_data_payment_max_number ( void );
 /*END_STATIC*/
@@ -796,6 +798,10 @@ gint gsb_data_payment_get_similar ( gint origin_payment,
 
 	if (tmp_payment -> account_number == target_account_number
 	    &&
+        payment -> payment_name
+        &&
+        tmp_payment -> payment_name
+        &&
 	    !strcmp (payment -> payment_name, tmp_payment -> payment_name)
 	    &&
 	    payment -> payment_sign == tmp_payment -> payment_sign)
@@ -816,26 +822,9 @@ gchar *gsb_data_payment_incremente_last_number ( gint payment_number,
 {
     const gchar *last_number;
     gchar *new_number;
-    gchar *prefix = NULL;
-    gint number = 0;
-    gint i = 0;
 
     last_number = gsb_data_payment_get_last_number ( payment_number );
-    if ( last_number && strlen ( last_number ) > 0 )
-    {
-        while ( last_number[i] == '0' )
-        {
-            i++;
-        }
-        if ( i > 0 )
-            prefix = g_strndup ( last_number, i );
-    }
-    
-    number = utils_str_atoi ( last_number );
-    number += increment;
-    new_number = utils_str_itoa ( number );
-    if ( prefix && strlen ( prefix ) > 0 )
-        new_number = g_strconcat ( prefix, new_number, NULL );
+    new_number = utils_str_incremente_number_from_str ( last_number, increment );
 
     return new_number;
 }
@@ -876,23 +865,26 @@ gboolean gsb_data_payment_set_last_number_from_int ( gint payment_number,
 					    gint last_number )
 {
     struct_payment *payment;
-    const gchar *old_number;
+    const gchar *old_number = NULL;
     gchar *new_number;
     gchar *prefix = NULL;
     gint i = 0;
 
     payment = gsb_data_payment_get_structure ( payment_number );
 
-    if (!payment)
-	return FALSE;
+    if ( !payment )
+        return FALSE;
 
     old_number = gsb_data_payment_get_last_number ( payment_number );
-    while ( old_number[i] == '0' )
+    if ( old_number )
     {
-        i++;
+        while ( old_number[i] == '0' )
+        {
+            i++;
+        }
+        if ( i > 0 )
+            prefix = g_strndup ( old_number, i );
     }
-    if ( i > 0 )
-        prefix = g_strndup ( old_number, i );
 
     new_number = utils_str_itoa ( last_number );
     if ( prefix && strlen ( prefix ) )
