@@ -26,24 +26,27 @@
  */
 
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "gsb_payment_method.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_mix.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_form.h"
-#include "./gsb_form_widget.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_form.h"
-#include "./gsb_data_form.h"
-#include "./erreur.h"
+#include "gsb_data_account.h"
+#include "gsb_data_mix.h"
+#include "gsb_data_payment.h"
+#include "gsb_form.h"
+#include "gsb_form_widget.h"
+#include "gsb_data_form.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
 static gint gsb_payment_method_get_payment_position ( GtkWidget *combo_box,
                         gint payment_number );
+static gboolean gsb_payment_method_set_cheque_entry ( gint payment_number );
 /*END_STATIC*/
 
 /*START_EXTERN*/
@@ -62,15 +65,16 @@ static gint gsb_payment_method_get_payment_position ( GtkWidget *combo_box,
  * \param sign GSB_PAYMENT_DEBIT or GSB_PAYMENT_CREDIT
  * \param account_number
  * \param exclude if we want to exclude a method of payment from the list, set the number here, else set 0
+ * \param TRUE if contra transaction
  *
  * \return FALSE if fail, TRUE if ok
  * */
 gboolean gsb_payment_method_create_combo_list ( GtkWidget *combo_box,
                         gint sign,
                         gint account_number,
-                        gint exclude )
+                        gint exclude,
+                        gboolean contra )
 {
-    GtkWidget *widget =  NULL;
     GtkListStore *store;
     GSList *tmp_list;
     gint store_filled = 0;
@@ -79,9 +83,7 @@ gboolean gsb_payment_method_create_combo_list ( GtkWidget *combo_box,
 	return FALSE;
 
     /* on bloque le signal du gtk_combo_box pour éviter de multiples appels */
-    widget = gsb_form_widget_get_widget (TRANSACTION_FORM_TYPE);
-    if ( widget )
-        g_signal_handlers_block_by_func (widget, 
+    g_signal_handlers_block_by_func ( combo_box, 
                         gsb_payment_method_changed_callback, NULL);
 
     /* we check first the existing model ; if none, we create it */
@@ -140,7 +142,6 @@ gboolean gsb_payment_method_create_combo_list ( GtkWidget *combo_box,
     /* if nothing in the store, hide it */
     if (store_filled)
     {
-        GtkWidget *cheque_entry;
         gint payment_number = 0;
 
         if ( sign == GSB_PAYMENT_DEBIT )
@@ -148,54 +149,20 @@ gboolean gsb_payment_method_create_combo_list ( GtkWidget *combo_box,
         else if ( sign == GSB_PAYMENT_CREDIT )
             payment_number = gsb_data_account_get_default_credit ( account_number );
 
-            gsb_payment_method_set_combobox_history ( combo_box, payment_number );
+        gsb_payment_method_set_combobox_history ( combo_box, payment_number, FALSE );
+        if ( contra == FALSE )
+            gsb_payment_method_show_cheque_entry_if_necessary ( payment_number );
 
-        gtk_widget_show (combo_box);
-
-        cheque_entry = gsb_form_widget_get_widget ( TRANSACTION_FORM_CHEQUE );
-
-        if ( gsb_data_payment_get_show_entry ( payment_number) )
-        {
-            /* set the next number if needed */
-            if ( cheque_entry
-             &&
-             gsb_data_payment_get_automatic_numbering ( payment_number ) )
-            {
-                    gchar* tmpstr;
-
-                    gsb_form_entry_get_focus (cheque_entry);
-                    
-                    tmpstr = gsb_data_payment_incremente_last_number ( payment_number, 1 );
-                    gtk_entry_set_text ( GTK_ENTRY (cheque_entry), tmpstr);
-                    g_free ( tmpstr );
-                    gtk_widget_show (cheque_entry);
-            }
-            else if ( cheque_entry )
-            {
-                gtk_entry_set_text ( GTK_ENTRY (cheque_entry),
-                         "" );
-                gsb_form_entry_lose_focus ( cheque_entry,
-                            FALSE,
-                            GINT_TO_POINTER ( TRANSACTION_FORM_CHEQUE ));
-                gtk_widget_show (cheque_entry);
-            }
-        }
-        else if ( cheque_entry )
-        {
-            gtk_entry_set_text ( GTK_ENTRY (cheque_entry),
-                         "" );
-            gsb_form_entry_lose_focus ( cheque_entry,
-                            FALSE,
-                            GINT_TO_POINTER ( TRANSACTION_FORM_CHEQUE ));
-            gtk_widget_hide ( cheque_entry );
-        }
+        gtk_widget_show ( combo_box );
     }
     else
     {
         gtk_widget_hide (combo_box);
+        gsb_payment_method_show_cheque_entry_if_necessary ( 0 );
     }
-    if ( widget )
-        g_signal_handlers_unblock_by_func (widget, 
+
+    /* on réactive le signal du gtk_combo_box */
+    g_signal_handlers_unblock_by_func ( combo_box, 
                         gsb_payment_method_changed_callback, NULL);
 
     return TRUE;
@@ -350,30 +317,48 @@ void gsb_payment_method_set_payment_position ( GtkWidget *combo_box,
  * \return TRUE if we can set the payment_number, FALSE if it's the default wich is set
  * */
 gboolean gsb_payment_method_set_combobox_history ( GtkWidget *combo_box,
-                        gint payment_number )
+                        gint payment_number,
+                        gboolean check_entry )
 {
     gint position;
     gboolean return_value;
     gint account_number;
 
-    account_number = gsb_data_payment_get_account_number (payment_number);
-    position = gsb_payment_method_get_payment_position ( combo_box,
-							 payment_number );
+    /* on sort si le moyen de paiement est déjà le bon */
+    if ( payment_number && gsb_payment_method_get_selected_number ( combo_box ) == payment_number )
+        return TRUE;
 
-    if (position != -1)
-	return_value = TRUE;
+    /* on bloque le signal du gtk_combo_box pour éviter de multiples appels */
+    g_signal_handlers_block_by_func ( combo_box, 
+                        gsb_payment_method_changed_callback, NULL);
+
+    account_number = gsb_data_payment_get_account_number (payment_number);
+    position = gsb_payment_method_get_payment_position ( combo_box, payment_number );
+
+    if ( position != -1 )
+        return_value = TRUE;
     else
     {
-	if ( gsb_payment_method_get_combo_sign (combo_box) == GSB_PAYMENT_CREDIT)
-	    position = gsb_payment_method_get_payment_position ( combo_box,
-								 gsb_data_account_get_default_credit (account_number));
-	else
-	    position = gsb_payment_method_get_payment_position ( combo_box,
-								 gsb_data_account_get_default_debit (account_number));
-	return_value = FALSE;
+        if ( gsb_payment_method_get_combo_sign ( combo_box ) == GSB_PAYMENT_CREDIT )
+            position = gsb_payment_method_get_payment_position ( combo_box,
+								gsb_data_account_get_default_credit ( account_number ) );
+        else if ( gsb_payment_method_get_combo_sign ( combo_box ) == GSB_PAYMENT_DEBIT )
+            position = gsb_payment_method_get_payment_position ( combo_box,
+								gsb_data_account_get_default_debit ( account_number ) );
+        else
+            position = 0;
+
+        return_value = FALSE;
     }
-    gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_box),
-			       position );
+    
+    gtk_combo_box_set_active ( GTK_COMBO_BOX (combo_box), position );
+    if ( check_entry )
+        gsb_payment_method_set_cheque_entry ( payment_number );
+
+    /* on réactive le signal du gtk_combo_box */
+    g_signal_handlers_unblock_by_func ( combo_box, 
+                        gsb_payment_method_changed_callback, NULL);
+
     return return_value;
 }
 
@@ -406,7 +391,7 @@ gboolean gsb_payment_method_changed_callback ( GtkWidget *combo_box,
     if ( gsb_data_payment_get_show_entry ( payment_number) )
     {
         /* set the next number if needed */
-        if (gsb_data_payment_get_automatic_numbering (payment_number) )
+        if (gsb_data_payment_get_automatic_numbering ( payment_number ) )
         {
             if ( gsb_form_widget_check_empty (cheque_entry) )
             {
@@ -435,12 +420,8 @@ gboolean gsb_payment_method_changed_callback ( GtkWidget *combo_box,
             }
         }
         else
-        {
-            gtk_entry_set_text ( GTK_ENTRY (cheque_entry), "" );
-            gsb_form_entry_lose_focus ( cheque_entry,
-                        FALSE,
-                        GINT_TO_POINTER ( TRANSACTION_FORM_CHEQUE ));
-        }
+            gsb_payment_method_set_cheque_entry ( 0 );
+
         gtk_widget_show (cheque_entry);
     }
     else
@@ -450,6 +431,83 @@ gboolean gsb_payment_method_changed_callback ( GtkWidget *combo_box,
 }
 
 
+/**
+ * show or hide the entry for cheque in the form
+ * if payment_number = 0 reset cheque_entry and hide it
+ *
+ * \param gint payment_number
+ *
+ * \return FALSE if not cheque_entry TRUE if OK
+ * */
+gboolean gsb_payment_method_set_cheque_entry ( gint payment_number )
+{
+    GtkWidget *cheque_entry;
+
+    cheque_entry = gsb_form_widget_get_widget ( TRANSACTION_FORM_CHEQUE );
+    if ( !cheque_entry )
+        return FALSE;
+
+    if ( gsb_data_payment_get_show_entry ( payment_number) == TRUE )
+    {
+        /* set the next number if needed */
+        if ( gsb_data_payment_get_automatic_numbering ( payment_number ) == TRUE )
+        {
+            gchar* tmpstr;
+
+            gsb_form_entry_get_focus ( cheque_entry );
+            
+            tmpstr = gsb_data_payment_incremente_last_number ( payment_number, 1 );
+            gtk_entry_set_text ( GTK_ENTRY (cheque_entry), tmpstr);
+            g_free ( tmpstr );
+            
+        }
+        else
+        {
+            gtk_entry_set_text ( GTK_ENTRY ( cheque_entry ), "" );
+            gsb_form_entry_lose_focus ( cheque_entry,
+                        FALSE,
+                        GINT_TO_POINTER ( TRANSACTION_FORM_CHEQUE ) );
+        }
+
+        gtk_widget_show ( cheque_entry );
+    }
+    else
+    {
+        gtk_entry_set_text ( GTK_ENTRY (cheque_entry), "" );
+        gsb_form_entry_lose_focus ( cheque_entry,
+                        FALSE,
+                        GINT_TO_POINTER ( TRANSACTION_FORM_CHEQUE ) );
+
+        gtk_widget_hide ( cheque_entry );
+    }
+    
+    return TRUE;
+}
+
+
+/**
+ * show or hide the entry for cheque in the form if necessary
+ *
+ * \param gint payment_number
+ *
+ * \return FALSE if not cheque_entry TRUE if OK
+ * */
+gboolean gsb_payment_method_show_cheque_entry_if_necessary ( gint payment_number )
+{
+    GtkWidget *cheque_entry;
+
+    cheque_entry = gsb_form_widget_get_widget ( TRANSACTION_FORM_CHEQUE );
+    if ( !cheque_entry )
+        return FALSE;
+
+    if ( gsb_data_payment_get_show_entry ( payment_number ) == TRUE )
+        gtk_widget_show ( cheque_entry );
+    else
+        gtk_widget_hide ( cheque_entry );
+
+    return TRUE;
+}
+
 
 /* Local Variables: */
 /* c-basic-offset: 4 */
