@@ -2,6 +2,7 @@
 /*                                                                            */
 /*     Copyright (C)    2000-2008 Cédric Auger (cedric@grisbi.org)            */
 /*          2003-2008 Benjamin Drieu (bdrieu@april.org)                       */
+/*                      2009-2010 Pierre Biava (grisbi@pierre.biava.name)     */
 /*          http://www.grisbi.org                                             */
 /*                                                                            */
 /*  This program is free software; you can redistribute it and/or modify      */
@@ -25,51 +26,62 @@
  * works with global variables of grisbi (initialisation...)
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "include.h"
 
 /*START_INCLUDE*/
 #include "traitement_variables.h"
-#include "./balance_estimate_data.h"
-#include "./gsb_currency.h"
-#include "./gsb_data_account.h"
-#include "./gsb_data_archive.h"
-#include "./gsb_data_archive_store.h"
-#include "./gsb_data_bank.h"
-#include "./gsb_data_budget.h"
-#include "./gsb_data_category.h"
-#include "./gsb_data_currency.h"
-#include "./gsb_data_currency_link.h"
-#include "./gsb_data_fyear.h"
-#include "./gsb_data_import_rule.h"
-#include "./gsb_data_partial_balance.h"
-#include "./gsb_data_payee.h"
-#include "./gsb_data_payment.h"
-#include "./gsb_data_print_config.h"
-#include "./gsb_data_reconcile.h"
-#include "./gsb_data_report_amout_comparison.h"
-#include "./gsb_data_report.h"
-#include "./gsb_data_report_text_comparison.h"
-#include "./gsb_data_scheduled.h"
-#include "./gsb_data_transaction.h"
-#include "./gsb_form_scheduler.h"
-#include "./gsb_form_widget.h"
-#include "./gsb_fyear.h"
-#include "./menu.h"
-#include "./import.h"
-#include "./gsb_report.h"
-#include "./gsb_scheduler_list.h"
-#include "./main.h"
-#include "./transaction_model.h"
-#include "./custom_list.h"
-#include "./gsb_transactions_list.h"
-#include "./include.h"
-#include "./gsb_scheduler_list.h"
-#include "./gsb_calendar.h"
-#include "./erreur.h"
-#include "./structures.h"
+#include "bet_data.h"
+#include "bet_data_finance.h"
+#include "bet_future.h"
+#include "custom_list.h"
+#include "fenetre_principale.h"
+#include "gsb_calendar.h"
+#include "gsb_currency.h"
+#include "gsb_data_account.h"
+#include "gsb_data_archive.h"
+#include "gsb_data_archive_store.h"
+#include "gsb_data_bank.h"
+#include "gsb_data_budget.h"
+#include "gsb_data_category.h"
+#include "gsb_data_currency.h"
+#include "gsb_data_currency_link.h"
+#include "gsb_data_fyear.h"
+#include "gsb_data_import_rule.h"
+#include "gsb_data_partial_balance.h"
+#include "gsb_data_payee.h"
+#include "gsb_data_payment.h"
+#include "gsb_data_print_config.h"
+#include "gsb_data_reconcile.h"
+#include "gsb_data_report_amout_comparison.h"
+#include "gsb_data_report.h"
+#include "gsb_data_report_text_comparison.h"
+#include "gsb_data_scheduled.h"
+#include "gsb_data_transaction.h"
+#include "gsb_form_scheduler.h"
+#include "gsb_form_widget.h"
+#include "gsb_fyear.h"
+#include "gsb_real.h"
+#include "gsb_report.h"
+#include "gsb_scheduler_list.h"
+#include "gsb_select_icon.h"
+#include "gsb_transactions_list.h"
+#include "import.h"
+#include "main.h"
+#include "menu.h"
+#include "structures.h"
+#include "transaction_model.h"
+#include "utils_dates.h"
+#include "utils_str.h"
+#include "erreur.h"
 /*END_INCLUDE*/
 
 /*START_STATIC*/
+static void initialise_format_date ( void );
+static void initialise_number_separators ( void );
 static void initialise_tab_affichage_ope ( void );
 /*END_STATIC*/
 
@@ -128,10 +140,17 @@ GdkColor couleur_nom_compte_prelight;
 
 GdkColor couleur_bleue;
 GdkColor couleur_jaune;
+
+/* colors for the balance estimate modul */
 GdkColor couleur_bet_division;
 GdkColor default_couleur_bet_division;
 GdkColor couleur_bet_future;
 GdkColor default_couleur_bet_future;
+GdkColor couleur_bet_solde;
+GdkColor default_couleur_bet_solde;
+GdkColor couleur_bet_transfert;
+GdkColor default_couleur_bet_transfert;
+
 
 GSList *liste_labels_titres_colonnes_liste_ope = NULL;
 
@@ -146,6 +165,7 @@ gchar *adresse_secondaire = NULL;
 extern gint affichage_echeances;
 extern gint affichage_echeances_perso_nb_libre;
 extern GtkTreeModel *bank_list_model;
+extern gint bet_array_col_width[BET_ARRAY_COLUMNS];
 extern GtkTreeStore *categ_tree_model;
 extern gint current_tree_view_width;
 extern GtkWidget *detail_devise_compte;
@@ -153,8 +173,6 @@ extern gint display_one_line;
 extern gint display_three_lines;
 extern gint display_two_lines;
 extern gint id_timeout;
-extern gchar *initial_file_title;
-extern gchar *initial_holder_title;
 extern gint mise_a_jour_fin_comptes_passifs;
 extern gint mise_a_jour_liste_comptes_accueil;
 extern gint mise_a_jour_liste_echeances_auto_accueil;
@@ -171,6 +189,7 @@ extern gint scheduler_current_tree_view_width;
 extern GtkWidget *solde_label;
 extern GtkWidget *solde_label_pointe;
 extern gint tab_affichage_ope[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS];
+extern gint transaction_col_align[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint transaction_col_width[CUSTOM_MODEL_N_VISIBLES_COLUMN];
 extern gint valeur_echelle_recherche_date_import;
 /*END_EXTERN*/
@@ -225,12 +244,23 @@ void init_variables ( void )
     /* the total of % of scheduled columns can be > 100 because all the columns are not showed at the same time */
     gint scheduler_col_width_init[SCHEDULER_COL_VISIBLE_COLUMNS] = {10, 12, 36, 12, 12, 12, 12 };
     gint transaction_col_width_init[CUSTOM_MODEL_VISIBLE_COLUMNS] = {10, 12, 36, 6, 12, 12, 12 };
+    gint bet_array_col_width_init[BET_ARRAY_COLUMNS] = {15, 40, 15, 15, 15 };
+    gint transaction_col_align_init[CUSTOM_MODEL_VISIBLE_COLUMNS] = { 1, 1, 0, 1, 2, 2, 2 };
     gint i;
     
 /* xxx on devrait séparer ça en 2 : les variables liées au fichier de compte, qui doivent être remises  à 0,
  * et les variables liées à grisbi (ex sauvegarde auto...) qui doivent rester */
     devel_debug (NULL);
 
+    /* init the new crypted file */
+    run.new_crypted_file = FALSE;
+
+    /* init the format date */
+    initialise_format_date ( );
+
+    /* init the decimal point and the thousands separator. */
+    initialise_number_separators ( );
+
     /* if ever there is still something from the previous list,
      * erase now */
     transaction_model_initialize();
@@ -290,20 +320,30 @@ void init_variables ( void )
     affichage_echeances_perso_nb_libre = 0;
     affichage_echeances_perso_j_m_a = PERIODICITY_DAYS;
 
-
     no_devise_totaux_tiers = 1;
     no_devise_totaux_categ = 1;
     no_devise_totaux_ib = 1;
 
-    /* initialization of titles */
+    /* initialization of titles and logo part */
+    if ( titre_fichier && strlen ( titre_fichier ) )
+        g_free ( titre_fichier );
     titre_fichier = g_strdup( _("My accounts") );
-    if ( initial_file_title && strlen ( initial_file_title ) )
-        g_free ( initial_file_title );
-    initial_file_title = NULL;
 
-    if ( initial_holder_title && strlen ( initial_holder_title ) )
-        g_free ( initial_holder_title );
-    initial_holder_title = NULL;
+    etat.is_pixmaps_dir = TRUE;
+    if ( etat.name_logo && strlen ( etat.name_logo ) )
+        g_free ( etat.name_logo );
+    etat.name_logo = NULL;
+    etat.utilise_logo = 1;
+    gsb_select_icon_init_logo_variables ();
+
+    /* reconcile (etat) */
+    etat.reconcile_account_number = -1;
+    if ( etat.reconcile_final_balance )
+        g_free ( etat.reconcile_final_balance );
+    etat.reconcile_final_balance = NULL;
+    if ( etat.reconcile_new_date )
+        g_date_free ( etat.reconcile_new_date );
+    etat.reconcile_new_date = NULL;
 
     adresse_commune = NULL;
     adresse_secondaire = NULL;
@@ -342,13 +382,25 @@ void init_variables ( void )
      * gsb_currency_update_combobox_currency_list */
     detail_devise_compte = NULL;
 
-    /* defaut value for width of columns */
+    /* defaut value for width and align of columns */
     for ( i = 0 ; i < CUSTOM_MODEL_VISIBLE_COLUMNS ; i++ )
-    transaction_col_width[i] = transaction_col_width_init[i];
-     for ( i = 0 ; i < SCHEDULER_COL_VISIBLE_COLUMNS ; i++ )
-    scheduler_col_width[i] = scheduler_col_width_init[i];
-    
+        transaction_col_width[i] = transaction_col_width_init[i];
+    for ( i = 0 ; i < CUSTOM_MODEL_VISIBLE_COLUMNS ; i++ )
+        transaction_col_align[i] = transaction_col_align_init[i];
+    for ( i = 0 ; i < SCHEDULER_COL_VISIBLE_COLUMNS ; i++ )
+        scheduler_col_width[i] = scheduler_col_width_init[i];
 
+    if ( run.transaction_column_width && strlen ( run.transaction_column_width ) )
+    {
+        g_free ( run.transaction_column_width );
+        run.transaction_column_width = NULL;
+    }
+    if ( run.scheduler_column_width && strlen ( run.scheduler_column_width ) )
+    {
+        g_free ( run.scheduler_column_width );
+        run.scheduler_column_width = NULL;
+    }
+    
     navigation_tree_view = NULL;
 
     /* free the form */
@@ -367,7 +419,9 @@ void init_variables ( void )
     text_color[1] = default_text_color[1];
     calendar_entry_color = default_calendar_entry_color;
 
+    /* divers */
     etat.add_archive_in_total_balance = TRUE;   /* add the archived transactions by default */
+    etat.get_fyear_by_value_date = 0;           /* By default use transaction-date */
 
     /* remove the timeout if necessary */
     if (id_timeout)
@@ -380,11 +434,16 @@ void init_variables ( void )
     categ_tree_model = NULL;
 
     /* initializes the variables for the estimate balance module */
-#ifdef ENABLE_BALANCE_ESTIMATE
     /* création de la liste des données à utiliser dans le tableau de résultats */
     bet_data_init_variables ( );
-#endif /* ENABLE_BALANCE_ESTIMATE */
+    /* initialisation des boites de dialogue */
+    bet_future_initialise_dialog ( );
     etat.bet_deb_period = 1;
+    /* defaut value for width of columns */
+    for ( i = 0 ; i < BET_ARRAY_COLUMNS ; i++ )
+        bet_array_col_width[i] = bet_array_col_width_init[i];
+
+    bet_data_finance_data_simulator_init ( );
 }
 
 
@@ -423,9 +482,9 @@ void initialisation_couleurs_listes ( void )
     default_text_color[1].blue = TEXT_COLOR_2_BLUE;
 
     /* selection color */
-    default_couleur_selection.red= SELECTION_COLOR_RED;
-    default_couleur_selection.green= SELECTION_COLOR_GREEN ;
-    default_couleur_selection.blue= SELECTION_COLOR_BLUE;
+    default_couleur_selection.red = SELECTION_COLOR_RED;
+    default_couleur_selection.green = SELECTION_COLOR_GREEN;
+    default_couleur_selection.blue = SELECTION_COLOR_BLUE;
 
     /* color of the non selectable transactions on scheduler */
     default_couleur_grise.red = UNSENSITIVE_SCHEDULED_COLOR_RED;
@@ -524,6 +583,24 @@ void initialisation_couleurs_listes ( void )
     default_couleur_bet_future.red = 31829;
     default_couleur_bet_future.green = 51015;
     default_couleur_bet_future.blue =  35908;
+
+    /* colors of the background bet solde data */
+    couleur_bet_solde.red = 2318;
+    couleur_bet_solde.green = 65535;
+    couleur_bet_solde.blue = 60331;
+
+    default_couleur_bet_solde.red = 2318;
+    default_couleur_bet_solde.green = 65535;
+    default_couleur_bet_solde.blue =  60331;
+
+    /* colors of the background bet transfert data */
+    couleur_bet_transfert.red = 31829;
+    couleur_bet_transfert.green = 51015;
+    couleur_bet_transfert.blue = 35908;
+
+    default_couleur_bet_transfert.red = 60035;
+    default_couleur_bet_transfert.green = 37622;
+    default_couleur_bet_transfert.blue =  59956;
 }
 /*****************************************************************************************************/
 
@@ -556,11 +633,13 @@ void menus_sensitifs ( gboolean sensitif )
     menu_name ( "ViewMenu",     "ShowTransactionForm",  NULL ),
     menu_name ( "ViewMenu",     "ShowGrid",             NULL ),
     menu_name ( "ViewMenu",     "ShowReconciled",       NULL ),
+    menu_name ( "ViewMenu",     "ShowArchived",         NULL ),
     menu_name ( "ViewMenu",     "ShowClosed",           NULL ),
     menu_name ( "ViewMenu",     "ShowOneLine",          NULL ),
     menu_name ( "ViewMenu",     "ShowTwoLines",         NULL ),
     menu_name ( "ViewMenu",     "ShowThreeLines",       NULL ),
     menu_name ( "ViewMenu",     "ShowFourLines",        NULL ),
+    menu_name ( "ViewMenu",     "InitwidthCol",        NULL ),
     NULL,
     };
     gchar ** tmp = items;
@@ -579,10 +658,67 @@ void menus_sensitifs ( gboolean sensitif )
     gsb_gui_sensitive_menu_item ( "EditMenu", "NewTransaction", NULL, FALSE );
     gsb_menu_transaction_operations_set_sensitive ( FALSE );
 }
-/*****************************************************************************************************/
+
+void menus_view_sensitifs ( gboolean sensitif )
+{
+    gchar * items[] = {
+    menu_name ( "ViewMenu",     "ShowTransactionForm",  NULL ),
+    menu_name ( "ViewMenu",     "ShowGrid",             NULL ),
+    menu_name ( "ViewMenu",     "ShowReconciled",       NULL ),
+    menu_name ( "ViewMenu",     "ShowArchived",         NULL ),
+    menu_name ( "ViewMenu",     "ShowClosed",           NULL ),
+    menu_name ( "ViewMenu",     "ShowOneLine",          NULL ),
+    menu_name ( "ViewMenu",     "ShowTwoLines",         NULL ),
+    menu_name ( "ViewMenu",     "ShowThreeLines",       NULL ),
+    menu_name ( "ViewMenu",     "ShowFourLines",        NULL ),
+    menu_name ( "ViewMenu",     "InitwidthCol",         NULL ),
+    NULL,
+    };
+    gchar **tmp = items;
+
+    devel_debug_int (sensitif);
+
+    while ( *tmp )
+    {
+        gsb_gui_sensitive_menu_item_from_string ( *tmp, sensitif );
+        tmp++;
+    }
+}
 
 
-/*****************************************************************************************************/
+/**
+ * initialise la largeur des colonnes du tableau d'affichage des opérations.
+ * ou des opérations planifiées.
+ *
+ * */
+void initialise_largeur_colonnes_tab_affichage_ope ( gint type_operation, const gchar *description )
+{
+    gchar **pointeur_char;
+    gint j;
+
+
+    /* the transactions columns are xx-xx-xx-xx and we want to set in transaction_col_width[1-2-3...] */
+    pointeur_char = g_strsplit ( description, "-", 0 );
+
+    if ( type_operation == GSB_ACCOUNT_PAGE )
+    {
+        for ( j = 0 ; j < CUSTOM_MODEL_VISIBLE_COLUMNS ; j++ )
+            transaction_col_width[j] = utils_str_atoi ( pointeur_char[j] );
+    }
+    else if ( type_operation == GSB_SCHEDULER_PAGE )
+    {
+        for ( j = 0 ; j < SCHEDULER_COL_VISIBLE_COLUMNS ; j++ )
+            scheduler_col_width[j] = utils_str_atoi ( pointeur_char[j] );
+    }
+
+        g_strfreev ( pointeur_char );
+}
+
+
+/**
+ * initialise le contenu du tableau d'affichage des opérations.
+ *
+ * */
 void initialise_tab_affichage_ope ( void )
 {
     gint tab[TRANSACTION_LIST_ROWS_NB][CUSTOM_MODEL_VISIBLE_COLUMNS] = {
@@ -599,11 +735,61 @@ void initialise_tab_affichage_ope ( void )
     for ( j = 0 ; j<CUSTOM_MODEL_VISIBLE_COLUMNS ; j++ )
         tab_affichage_ope[i][j] = tab[i][j];
 
-    /* by default, the display of lines is 1, 1-2, 1-2-4 */
+    /* by default, the display of lines is 1, 1-2, 1-2-3 */
     display_one_line = 0;
     display_two_lines = 0;
-    display_three_lines = 1;
+    display_three_lines = 0;
 }
+
+
+/**
+ * init the format of date.
+ *
+ * */
+void initialise_format_date ( void )
+{
+    const gchar *langue;
+
+    gsb_date_set_format_date ( NULL );
+
+    langue = g_getenv ( "LANG");
+
+    if ( g_str_has_prefix ( langue, "en_" ) || g_str_has_prefix ( langue, "cs_" ) )
+        gsb_date_set_format_date ( "%m/%d/%Y" );
+    else
+        gsb_date_set_format_date ( "%d/%m/%Y" );
+}
+
+
+/**
+ * init the decimal point and the thousands separator.
+ *
+ * */
+void initialise_number_separators ( void )
+{
+    struct lconv *conv;
+    gchar *dec_point = NULL, *thousand_sep = NULL;
+
+    gsb_real_set_decimal_point ( NULL );
+    gsb_real_set_thousands_sep ( NULL );
+
+    conv = localeconv();
+
+    if ( conv->mon_decimal_point && strlen ( conv->mon_decimal_point ) )
+    {
+        dec_point = g_locale_to_utf8 ( conv->mon_decimal_point, -1, NULL, NULL, NULL );
+        gsb_real_set_decimal_point ( dec_point );
+        g_free ( dec_point );
+    }
+    else
+        gsb_real_set_decimal_point ( "." );
+
+    thousand_sep = g_locale_to_utf8 ( conv->mon_thousands_sep, -1, NULL, NULL, NULL );
+    gsb_real_set_thousands_sep ( thousand_sep );
+    g_free ( thousand_sep );
+}
+
+
 /* Local Variables: */
 /* c-basic-offset: 4 */
 /* End: */
